@@ -87,21 +87,21 @@ def form_links(allure_links):
     return links
 
 
-def form_setup_teardown(data_before_after, uuid, requests, path):
+def form_setup_teardown(data_before_after, test_uuid, requests, path):
     setup = []
     teardown = []
     results_setup = []
     results_teardown = []
 
-    if uuid:
-        for time in data_before_after:
-            if 'children' in data_before_after[time]:
-                for child in data_before_after[time]['children']:
-                    if child == uuid:
-                        steps, results_steps = form_steps(data_before_after[time].get('befores'), requests, path)
+    if test_uuid:
+        for uuid in data_before_after:
+            if 'children' in data_before_after[uuid]:
+                for child in data_before_after[uuid]['children']:
+                    if child == test_uuid:
+                        steps, results_steps = form_steps(data_before_after[uuid].get('befores'), requests, path)
                         setup += steps
                         results_setup += results_steps
-                        steps, results_steps = form_steps(data_before_after[time].get('afters'), requests, path)
+                        steps, results_steps = form_steps(data_before_after[uuid].get('afters'), requests, path)
                         teardown += steps
                         results_teardown += results_steps
 
